import type { ParsedSearchQuery } from '../searchParser/index.js';
import type { DataRecord } from '../types/DataRecord.js';
import type { PaginatedListRequest } from '../types/PaginatedListRequest.js';
import { AbstractDataSource } from './AbstractDataSource.js';
export interface LocalDataSourceOptions<T extends DataRecord> {
    filtering?: {
        textSearchColumns?: (keyof T)[];
        filterFunction?: (item: T, searchQuery: ParsedSearchQuery) => boolean;
    };
}
/**
 * The local data source requires the data to be passed in as an array.
 * The datatable is still paginated, sorted and searchable by performing everything on the clientside
 */
export declare class LocalDataSource<T extends DataRecord = DataRecord> extends AbstractDataSource<T> {
    private data;
    private options;
    /**
     * Create a new local data source to use the passed in array as data.
     *
     * @param data array with all table entries
     * @param options
     */
    constructor(data: T[], options?: LocalDataSourceOptions<T>);
    requestData(data: PaginatedListRequest<T>): void;
    private filterData;
    private sortData;
}
